EXPORTS
	??1CSTUNBinding@@UAE@XZ @ 1 NONAME ; CSTUNBinding::~CSTUNBinding(void)
	??1CSTUNClient@@UAE@XZ @ 2 NONAME ; CSTUNClient::~CSTUNClient(void)
	??1CSTUNRelayBinding@@UAE@XZ @ 3 NONAME ; CSTUNRelayBinding::~CSTUNRelayBinding(void)
	?AddressResolved@CSTUNBinding@@UBEHXZ @ 4 NONAME ; int CSTUNBinding::AddressResolved(void) const
	?AddressResolved@CSTUNRelayBinding@@UBEHXZ @ 5 NONAME ; int CSTUNRelayBinding::AddressResolved(void) const
	?AllocateRequestL@CSTUNRelayBinding@@QAEXI@Z @ 6 NONAME ; void CSTUNRelayBinding::AllocateRequestL(unsigned int)
	?AlternateServerAddr@CSTUNBinding@@UBEABVTInetAddr@@XZ @ 7 NONAME ; class TInetAddr const & CSTUNBinding::AlternateServerAddr(void) const
	?AlternateServerAddr@CSTUNRelayBinding@@UBEABVTInetAddr@@XZ @ 8 NONAME ; class TInetAddr const & CSTUNRelayBinding::AlternateServerAddr(void) const
	?CancelRequest@CSTUNBinding@@UAEXXZ @ 9 NONAME ; void CSTUNBinding::CancelRequest(void)
	?CancelRequest@CSTUNRelayBinding@@UAEXXZ @ 10 NONAME ; void CSTUNRelayBinding::CancelRequest(void)
	?CancelRetransmission@CSTUNBinding@@QAEXXZ @ 11 NONAME ; void CSTUNBinding::CancelRetransmission(void)
	?ConnectRequestL@CSTUNRelayBinding@@QAEXABVTInetAddr@@@Z @ 12 NONAME ; void CSTUNRelayBinding::ConnectRequestL(class TInetAddr const &)
	?ConnectionId@CSTUNBinding@@UBEIXZ @ 13 NONAME ; unsigned int CSTUNBinding::ConnectionId(void) const
	?ConnectionId@CSTUNRelayBinding@@UBEIXZ @ 14 NONAME ; unsigned int CSTUNRelayBinding::ConnectionId(void) const
	?HandleDataL@CSTUNBinding@@UAEPAVHBufC8@@ABVTDesC8@@AAHAAVTInetAddr@@@Z @ 15 NONAME ; class HBufC8 * CSTUNBinding::HandleDataL(class TDesC8 const &, int &, class TInetAddr &)
	?HandleDataL@CSTUNRelayBinding@@UAEPAVHBufC8@@ABVTDesC8@@AAHAAVTInetAddr@@@Z @ 16 NONAME ; class HBufC8 * CSTUNRelayBinding::HandleDataL(class TDesC8 const &, int &, class TInetAddr &)
	?IsInitialized@CSTUNClient@@QBEHXZ @ 17 NONAME ; int CSTUNClient::IsInitialized(void) const
	?NewL@CSTUNBinding@@SAPAV1@AAVCSTUNClient@@AAVRSocket@@@Z @ 18 NONAME ; class CSTUNBinding * CSTUNBinding::NewL(class CSTUNClient &, class RSocket &)
	?NewL@CSTUNBinding@@SAPAV1@AAVCSTUNClient@@II@Z @ 19 NONAME ; class CSTUNBinding * CSTUNBinding::NewL(class CSTUNClient &, unsigned int, unsigned int)
	?NewL@CSTUNClient@@SAPAV1@HAAVCDeltaTimer@@AAVMSTUNClientObserver@@PAVMNcmConnectionMultiplexer@@W4TTransportProtocol@@@Z @ 20 NONAME ; class CSTUNClient * CSTUNClient::NewL(int, class CDeltaTimer &, class MSTUNClientObserver &, class MNcmConnectionMultiplexer *, enum TTransportProtocol)
	?NewL@CSTUNClient@@SAPAV1@HABVTDesC8@@I0AAVRSocketServ@@AAVRConnection@@AAVCDeltaTimer@@AAVMSTUNClientObserver@@HHHPAVMNcmConnectionMultiplexer@@W4TTransportProtocol@@@Z @ 21 NONAME ; class CSTUNClient * CSTUNClient::NewL(int, class TDesC8 const &, unsigned int, class TDesC8 const &, class RSocketServ &, class RConnection &, class CDeltaTimer &, class MSTUNClientObserver &, int, int, int, class MNcmConnectionMultiplexer *, enum TTransportProtocol)
	?NewL@CSTUNRelayBinding@@SAPAV1@AAVCSTUNClient@@II@Z @ 22 NONAME ; class CSTUNRelayBinding * CSTUNRelayBinding::NewL(class CSTUNClient &, unsigned int, unsigned int)
	?NewLC@CSTUNBinding@@SAPAV1@AAVCSTUNClient@@AAVRSocket@@@Z @ 23 NONAME ; class CSTUNBinding * CSTUNBinding::NewLC(class CSTUNClient &, class RSocket &)
	?NewLC@CSTUNBinding@@SAPAV1@AAVCSTUNClient@@II@Z @ 24 NONAME ; class CSTUNBinding * CSTUNBinding::NewLC(class CSTUNClient &, unsigned int, unsigned int)
	?NewLC@CSTUNClient@@SAPAV1@HAAVCDeltaTimer@@AAVMSTUNClientObserver@@PAVMNcmConnectionMultiplexer@@W4TTransportProtocol@@@Z @ 25 NONAME ; class CSTUNClient * CSTUNClient::NewLC(int, class CDeltaTimer &, class MSTUNClientObserver &, class MNcmConnectionMultiplexer *, enum TTransportProtocol)
	?NewLC@CSTUNClient@@SAPAV1@HABVTDesC8@@I0AAVRSocketServ@@AAVRConnection@@AAVCDeltaTimer@@AAVMSTUNClientObserver@@HHHPAVMNcmConnectionMultiplexer@@W4TTransportProtocol@@@Z @ 26 NONAME ; class CSTUNClient * CSTUNClient::NewLC(int, class TDesC8 const &, unsigned int, class TDesC8 const &, class RSocketServ &, class RConnection &, class CDeltaTimer &, class MSTUNClientObserver &, int, int, int, class MNcmConnectionMultiplexer *, enum TTransportProtocol)
	?NewLC@CSTUNRelayBinding@@SAPAV1@AAVCSTUNClient@@II@Z @ 27 NONAME ; class CSTUNRelayBinding * CSTUNRelayBinding::NewLC(class CSTUNClient &, unsigned int, unsigned int)
	?ObtainTransactionIDL@CSTUNClient@@QAEXAAVTDesC8@@@Z @ 28 NONAME ; void CSTUNClient::ObtainTransactionIDL(class TDesC8 &)
	?PublicAddr@CSTUNBinding@@UBEABVTInetAddr@@XZ @ 29 NONAME ; class TInetAddr const & CSTUNBinding::PublicAddr(void) const
	?PublicAddr@CSTUNRelayBinding@@UBEABVTInetAddr@@XZ @ 30 NONAME ; class TInetAddr const & CSTUNRelayBinding::PublicAddr(void) const
	?RealmFromResponse@CSTUNBinding@@UBEPBVHBufC8@@XZ @ 31 NONAME ; class HBufC8 const * CSTUNBinding::RealmFromResponse(void) const
	?RealmFromResponse@CSTUNRelayBinding@@UBEPBVHBufC8@@XZ @ 32 NONAME ; class HBufC8 const * CSTUNRelayBinding::RealmFromResponse(void) const
	?RelayAddr@CSTUNRelayBinding@@QBEABVTInetAddr@@XZ @ 33 NONAME ; class TInetAddr const & CSTUNRelayBinding::RelayAddr(void) const
	?STUNClient@CSTUNBinding@@UBEPBVCSTUNClient@@XZ @ 34 NONAME ; class CSTUNClient const * CSTUNBinding::STUNClient(void) const
	?STUNClient@CSTUNRelayBinding@@UBEPBVCSTUNClient@@XZ @ 35 NONAME ; class CSTUNClient const * CSTUNRelayBinding::STUNClient(void) const
	?STUNServerAddrL@CSTUNClient@@QBEABVTInetAddr@@XZ @ 36 NONAME ; class TInetAddr const & CSTUNClient::STUNServerAddrL(void) const
	?SendIndicationL@CSTUNBinding@@UAEXABVTInetAddr@@ABVTDesC8@@H@Z @ 37 NONAME ; void CSTUNBinding::SendIndicationL(class TInetAddr const &, class TDesC8 const &, int)
	?SendIndicationL@CSTUNRelayBinding@@UAEXABVTInetAddr@@ABVTDesC8@@H@Z @ 38 NONAME ; void CSTUNRelayBinding::SendIndicationL(class TInetAddr const &, class TDesC8 const &, int)
	?SendRequestL@CSTUNBinding@@QAEXABVTInetAddr@@HI@Z @ 39 NONAME ; void CSTUNBinding::SendRequestL(class TInetAddr const &, int, unsigned int)
	?SendRequestL@CSTUNBinding@@QAEXXZ @ 40 NONAME ; void CSTUNBinding::SendRequestL(void)
	?SetActiveDestinationRequestL@CSTUNRelayBinding@@QAEXABVTInetAddr@@AAK@Z @ 41 NONAME ; void CSTUNRelayBinding::SetActiveDestinationRequestL(class TInetAddr const &, unsigned long &)
	?SetCredentialsL@CSTUNClient@@QAEXABVTDesC8@@0@Z @ 42 NONAME ; void CSTUNClient::SetCredentialsL(class TDesC8 const &, class TDesC8 const &)
	?SetICESpecificAttributes@CSTUNBinding@@UAEXABVTICEAttributes@@@Z @ 43 NONAME ; void CSTUNBinding::SetICESpecificAttributes(class TICEAttributes const &)
	?SetICESpecificAttributes@CSTUNRelayBinding@@UAEXABVTICEAttributes@@@Z @ 44 NONAME ; void CSTUNRelayBinding::SetICESpecificAttributes(class TICEAttributes const &)
	?SharedSecretObtained@CSTUNClient@@QBEHXZ @ 45 NONAME ; int CSTUNClient::SharedSecretObtained(void) const
	?Socket@CSTUNBinding@@QBEABVRSocket@@XZ @ 46 NONAME ; class RSocket const & CSTUNBinding::Socket(void) const
	?StreamId@CSTUNBinding@@UBEIXZ @ 47 NONAME ; unsigned int CSTUNBinding::StreamId(void) const
	?StreamId@CSTUNRelayBinding@@UBEIXZ @ 48 NONAME ; unsigned int CSTUNRelayBinding::StreamId(void) const
	?__DbgTestInvariant@CSTUNBinding@@QBEXXZ @ 49 NONAME ; void CSTUNBinding::__DbgTestInvariant(void) const
	?__DbgTestInvariant@CSTUNClient@@QBEXXZ @ 50 NONAME ; void CSTUNClient::__DbgTestInvariant(void) const
	?__DbgTestInvariant@CSTUNClientImplementation@@QBEXXZ @ 51 NONAME ; void CSTUNClientImplementation::__DbgTestInvariant(void) const
	?__DbgTestInvariant@CSTUNRelayBinding@@QBEXXZ @ 52 NONAME ; void CSTUNRelayBinding::__DbgTestInvariant(void) const
	?__DbgTestInvariant@CSTUNSharedSecret@@QBEXXZ @ 53 NONAME ; void CSTUNSharedSecret::__DbgTestInvariant(void) const
	?__DbgTestInvariant@CSTUNTransaction@@QBEXXZ @ 54 NONAME ; void CSTUNTransaction::__DbgTestInvariant(void) const

